# Orca
#
# Copyright 2006 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

"""Holds platform-specific settings.
"""

__id__        = "$Id: platform.py.in,v 1.2 2006/06/10 00:54:47 wwalker Exp $"
__version__   = "$Revision: 1.2 $"
__date__      = "$Date: 2006/06/10 00:54:47 $"
__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
__license__   = "LGPL"

# $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
#
version     = "2.21.4"

# "--prefix" parameter used when configuring the build.
#
prefix      = "/usr/local"

# The package name (should be "orca").
#
package     = "orca"

# The name of the data directory (usually "share").
#
datadirname = "share"
